<?php
/**
 * @file
 * Defines list field types that can be used with the Options module.
 */

/**
 * Implements hook_help().
 */
function tinkoff_credit_help($path, $arg) {

}

/**
 * Implements hook_field_info().
 */
function tinkoff_credit_field_info() {
  return array(
    'tinkoff_credit_promocodes_list' => array(
      'label' => t('Tinkoff credit'),
      'description' => t("This field stores text values from a list of allowed 'value => label' pairs, i.e. 'US States': IL => Illinois, IA => Iowa, IN => Indiana."),
      'settings' => array('promocodes' => array(), 'promocodes_function' => ''),
      'default_widget' => 'options_select',
      'default_formatter' => 'tinkoff_credit_default',
    ),
  );
}

/**
 * Implements hook_field_update_field().
 */
function tinkoff_credit_field_update_field($field, $prior_field, $has_data) {
  drupal_static_reset('tinkoff_credit_promocodes_list');
}


/**
 * Checks if a list of values are being used in actual field values.
 */
function _tinkoff_credit_values_in_use($field, $values) {
  if ($values) {
    $query = new EntityFieldQuery();
    $found = $query
      ->fieldCondition($field['field_name'], 'value', $values)
      ->range(0, 1)
      ->execute();
    return !empty($found);
  }

  return FALSE;
}

/**
 * Implements hook_field_validate().
 *
 * Possible error codes:
 * - 'tinkoff_credit_illegal_value': The value is not part of the list of
 * allowed values.
 */
function tinkoff_credit_field_validate($entity_type, $entity, $field, $instance, $langcode, $items, &$errors) {
  $promocodes = tinkoff_credit_get_promocodes();
  foreach ($items as $delta => $item) {
    if (!empty($item['value'])) {
      if (!empty($promocodes) && !isset($promocodes[$item['value']])) {
        $errors[$field['field_name']][$langcode][$delta][] = array(
          'error' => 'tinkoff_credit_illegal_value',
          'message' => t('%name: illegal value.', array('%name' => $instance['label'])),
        );
      }
    }
  }
}

/**
 * Implements hook_field_is_empty().
 */
function tinkoff_credit_field_is_empty($item, $field) {
  if (empty($item['value']) && (string) $item['value'] !== '0') {
    return TRUE;
  }
  return FALSE;
}

/**
 * Implements hook_field_widget_info_alter().
 */
function tinkoff_credit_field_widget_info_alter(&$info) {
  $widgets = array(
    'options_select' => array('tinkoff_credit_promocodes_list'),
  );

  foreach ($widgets as $widget => $field_types) {
    $info[$widget]['field types'] = array_merge($info[$widget]['field types'], $field_types);
  }
}

/**
 * Implements hook_options_list().
 */
function tinkoff_credit_options_list($field, $instance, $entity_type, $entity) {
  $query = db_select('tinkoff_credit_promocodes', 'tcp');
  $query->fields('tcp', array('id', 'promocode_name'));
  $query->execute();
  $result = $query->execute();
  $items = array();
  foreach ($result as $row) {
    $items[$row->id] = $row->promocode_name;
  }
  return empty($items) ? FALSE : $items;
}

/**
 * Implements hook_field_formatter_info().
 */
function tinkoff_credit_field_formatter_info() {
  return array(
    'tinkoff_credit_default' => array(
      'label' => t('Default'),
      'field types' => array('tinkoff_credit_promocodes_list'),
    ),
//    'tinkoff_credit_key' => array(
//      'label' => t('Key'),
//      'field types' => array('tinkoff_credit_promocodes_list'),
//    ),
  );
}

/**
 * Implements hook_field_formatter_view().
 */
function tinkoff_credit_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $element = array();

  switch ($display['type']) {
    case 'tinkoff_credit_default':
      $promocodes = tinkoff_credit_get_promocodes();
      foreach ($items as $delta => $item) {
        if (isset($promocodes[$item['value']])) {
          $value = $promocodes[$item['value']]['type'];
          $element[$delta] = array(
            '#type' => 'button',
            '#value' => tinkoff_credit_get_button_type($value),
            '#attributes' => array(
              'id' => 'buy-in-credit-button',
              'data-product-id' => $entity->product_id,
            ),
          );
          $element['#attached']['js'][] = drupal_get_path('module', 'tinkoff_credit') . '/js/tinkoff_credit.js';
        }
      }
      break;

//    case 'tinkoff_credit_key':
//      foreach ($items as $delta => $item) {
//        $element[$delta] = array('#markup' => field_filter_xss($item['value']));
//      }
//      break;
  }

  return $element;
}

function tinkoff_credit_form_field_ui_field_edit_form_alter(&$form, &$form_state, $form_id) {
  if ($form['#field']['type'] == 'tinkoff_credit_promocodes_list') {
    $form['field']['cardinality']['#options'] = array(1);
  }
}
